'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var Adapter = require('../adapter');
var _ = require('./courseware/helpers');
var ManifestMetadata = require('./courseware/manifestMetadata');
var OrganizationItem = require('./courseware/organization');
var Resource = require('./courseware/resource');
var CONSTANTS = require('./courseware/constants');
var CARTRIDGE_TYPES = CONSTANTS.CARTRIDGE_TYPES;

/**
 * Adapter to transform raw courseware assembly query results into transformation syntax.
 */

var Courseware = function (_Adapter) {
  _inherits(Courseware, _Adapter);

  function Courseware() {
    _classCallCheck(this, Courseware);

    return _possibleConstructorReturn(this, (Courseware.__proto__ || Object.getPrototypeOf(Courseware)).apply(this, arguments));
  }

  _createClass(Courseware, [{
    key: 'setup',
    value: function setup() {
      this._resources = [];
      this._root = _.shallowClone(this._);
      this._children = this._.children;
      this._whitelist = this._.benchmark;
      this._env = this._options.environment;
    }
  }, {
    key: 'metadata',
    get: function get() {
      return Object.assign({}, new ManifestMetadata(this._root, this._template));
    }
  }, {
    key: 'organizations',
    get: function get() {
      var _this2 = this;

      var items = this._children;
      var addOn = items.find(function (item) {
        return _.isAddOn(item);
      });
      var whitelist = this._whitelist;
      var listItems = items.sort(_.orderByType).filter(function (item) {
        return _.isPermitted(item, whitelist);
      }).map(function (item) {
        return new OrganizationItem(item, _this2._template, _this2._resources, whitelist);
      });

      if (addOn) {
        listItems.push(new OrganizationItem(addOn, this._template, this._resources, whitelist));
      }

      return {
        organization: {
          item: {
            item: listItems
          }
        }
      };
    }
  }, {
    key: 'resources',
    get: function get() {
      var _this3 = this;

      var listItems = this._resources;
      var courseXid = _.courseXid(this._root);

      if (!listItems || !listItems.length) {
        return {};
      }

      listItems = listItems.map(function (_ref) {
        var item = _ref.item,
            identifier = _ref.identifier;

        var type = _.getCartridgeType(item);
        var filename = 'resources/' + type + '/' + identifier + '.xml';
        switch (type) {
          case CARTRIDGE_TYPES.WEB_LINK:
            // <webLink />
            if (_this3._options.useExternal) {
              var _ref2 = new Resource.ExternalWebLinkItem(item, _this3._template, identifier, filename),
                  REFERENCE = _ref2.REFERENCE,
                  FILE = _ref2.FILE;

              _this3.addExternal(filename, { webLink: FILE });
              return REFERENCE;
            }
            return new Resource.WebLinkItem(item, _this3._template, identifier);
          case CARTRIDGE_TYPES.BASIC_LTI_LINK:
            // <cartridge_basiclti_link />
            if (_this3._options.useExternal) {
              var _ref3 = new Resource.ExternalBasicLTILinkItem(item, _this3._template, identifier, filename, courseXid, _this3._env),
                  _REFERENCE = _ref3.REFERENCE,
                  _FILE = _ref3.FILE;

              _this3.addExternal(filename, { cartridge_basiclti_link: _FILE });
              return _REFERENCE;
            }
            return new Resource.BasicLTILinkItem(item, _this3._template, identifier, courseXid, _this3._env);
          default:
            // Testing purposes only. Nothing should ever reach this, all resources should be handled above.
            return { $: { identifier: identifier } };
        }
      });

      return {
        resource: listItems
      };
    }
  }]);

  return Courseware;
}(Adapter);

module.exports = Courseware;