'use strict';

var flatten = require('lodash/flatten');
var values = require('lodash/values');

var ENVS = {
  DEV: 'dev',
  QASTG: 'qastg',
  QALV: 'qalv',
  DEMO: 'demo',
  PQA: 'pqa',
  PROD: 'prod'
};
var NODE_ENV = process.env.NODE_ENV;
NODE_ENV = NODE_ENV ? NODE_ENV.toUpperCase() : 'DEV';

var ENV = ENVS[NODE_ENV] || ENVS.DEV;

var NOOP_ARRAY = [{}];

// LURE LTI URL
var BASE_LURE_URL = function BASE_LURE_URL(env) {
  env = env ? ENVS[env.toUpperCase()] || ENV : ENV;
  var subdomain = env === ENVS.PROD ? 'router-integration' : 'lure-' + env + '.integration.nonprod';

  return subdomain + '.mheducation.com';
};

// `NODE_TYPES` define the organization of the courseware.
var NODE_TYPES = {
  COURSE: 'course',
  ADD_ON: 'addOn',
  NODE: 'node',
  SECTION: 'section',
  SUBSECTION: 'subsection'

  // `ASSET_TYPES` represent the resources of the courseware.
};var ASSET_TYPES = {
  EBOOK: 'EBOOK',
  SMARTBOOK: 'SMARTBOOK',
  CHAPTER: 'CHAPTER',
  ECHAPTER: 'ECHAPTER',
  DOC: 'DOC',
  DOCX: 'DOCX',
  PDF: 'PDF',
  URL: 'URL',
  HYPERLINK: 'HYPERLINK',
  IMAGE: 'IMAGE',
  AUDIO: 'AUDIO',
  VIDEO: 'VIDEO',
  XLS: 'XLS',
  XLSX: 'XLSX',
  PPT: 'PPT',
  PPTX: 'PPTX',
  DIVIDER: 'SECTION-DIVIDER',
  ASSESSMENT: 'LARS-ASSESSMENT',
  ZIP: 'ZIP',
  // Currently unhandled (unsupported) types.
  BANK: 'LARS-BANK',
  BANK_PASSAGE: 'BANK-PASSAGE',
  BANK_QUESTION: 'BANK-QUESTION',
  BANK_ASSESSMENT: 'BANK-ASSESSMENT',
  BOK: 'BOK',
  CLO: 'CLO',
  CSV: 'CSV',
  EMBED: 'EMBED-VIDEO',
  FLV: 'FLV',
  GSP: 'GSP',
  HTML: 'HTML',
  TEST_BANK: 'TESTBANK',
  // Unhandled type used for coverage.
  NOOP: 'NOOP'

  // Human readable labels for types. `null` for types that do not display a label.
};var ASSET_TYPE_ALIASES = Object.assign({}, ASSET_TYPES, {
  EBOOK: 'eBook',
  SMARTBOOK: 'Smartbook',
  CHAPTER: 'eBook Chapter',
  ECHAPTER: 'eBook Chapter',
  DOC: 'Word Document',
  DOCX: 'Word Document',
  VIDEO: 'Video',
  URL: null,
  HYPERLINK: null,
  XLS: 'Excel Spreadsheet',
  XLSX: 'Excel Spreadsheet',
  PPT: 'PowerPoint Presentation',
  PPTX: 'PowerPoint Presentation',
  ASSESSMENT: 'Assessment',
  ZIP: 'Zip Archive'
});

var LAUNCHABLE_TYPES = {
  INTERACTIVE: 'INTERACTIVE',
  BASIC: 'BASIC',
  STATIC: {
    AUDIO: 'AUDIO',
    IMAGE: 'IMAGE',
    VIDEO: 'VIDEO'
  }

  /**
   * Generic type map grouping (for viewer).
   */
};var LAUNCHABLE_TYPE_GROUPS = {
  INTERACTIVE: [ASSET_TYPES.EBOOK, ASSET_TYPES.SMARTBOOK, ASSET_TYPES.CHAPTER, ASSET_TYPES.ECHAPTER, ASSET_TYPES.ASSESSMENT],
  BASIC: [ASSET_TYPES.URL, ASSET_TYPES.HYPERLINK,
  // FILES
  ASSET_TYPES.PDF, ASSET_TYPES.DOC, ASSET_TYPES.DOCX, ASSET_TYPES.XLS, ASSET_TYPES.XLSX, ASSET_TYPES.PPT, ASSET_TYPES.PPTX, ASSET_TYPES.ZIP],
  STATIC: {
    AUDIO: [ASSET_TYPES.AUDIO],
    IMAGE: [ASSET_TYPES.IMAGE],
    VIDEO: [ASSET_TYPES.VIDEO]
  }

  /**
   * Skip render labels for the following nodes.
   */
};var LABEL_BLACKLIST = [NODE_TYPES.COURSE];

/**
 * Common Cartridge types
 */
var CARTRIDGE_TYPES = {
  WEB_LINK: 'webLink',
  BASIC_LTI_LINK: 'basicLTILink'

  /**
   * <webLink />
   *
   * Insecure links
   */
};var WEB_LINK_RESOURCES = [ASSET_TYPES.URL, ASSET_TYPES.HYPERLINK];

/**
 * <cartridge_basiclti_link />
 *
 * Secure links
 */
var BASIC_LTI_RESOURCES = [ASSET_TYPES.EBOOK, ASSET_TYPES.SMARTBOOK, ASSET_TYPES.CHAPTER, ASSET_TYPES.ECHAPTER, ASSET_TYPES.PDF, ASSET_TYPES.VIDEO, ASSET_TYPES.DOC, ASSET_TYPES.DOCX, ASSET_TYPES.XLS, ASSET_TYPES.XLSX, ASSET_TYPES.PPT, ASSET_TYPES.PPTX, ASSET_TYPES.ZIP];

var COURSEWARE_WHITELIST_KEYS = {
  COURSE: 'courseUuid',
  DOCUMENT: 'documentUuid',
  AUTHORITY: 'authorityUuid',
  SUBJECT_DOCUMENT: 'subjectDocumentUuid'
};

var BENTO_WHITELIST_KEYS = {
  COURSE: 'course',
  DOCUMENT: 'document',
  AUTHORITY: 'authority',
  SUBJECT_DOCUMENT: 'subject_doc'
};

var ASSET_TYPE_VALUES = values(ASSET_TYPES);

/**
 * Permit the types (node|asset), anything not permitted will need to be handled manually.
 */
var PERMITTED_TYPES = flatten([NODE_TYPES.NODE, NODE_TYPES.SECTION, WEB_LINK_RESOURCES, BASIC_LTI_RESOURCES, ASSET_TYPES.NOOP]);

/**
 * Language ISO
 */
var LANGUAGE_CODE_MAP = {
  English: 'en',
  Spanish: 'es'
};
var COUNTRY_CODE_MAP = {
  'United States of America': 'US'

  /**
   * Services available to LURE
   */
};var LURE_SERVICES = {
  LARS: 'LARS',
  ZIRA: 'ZIRA'
};

module.exports = {
  NOOP_ARRAY: NOOP_ARRAY,
  BASE_LURE_URL: BASE_LURE_URL,
  NODE_TYPES: NODE_TYPES,
  ASSET_TYPES: ASSET_TYPES,
  ASSET_TYPE_ALIASES: ASSET_TYPE_ALIASES,
  LAUNCHABLE_TYPES: LAUNCHABLE_TYPES,
  LAUNCHABLE_TYPE_GROUPS: LAUNCHABLE_TYPE_GROUPS,
  LABEL_BLACKLIST: LABEL_BLACKLIST,
  CARTRIDGE_TYPES: CARTRIDGE_TYPES,
  WEB_LINK_RESOURCES: WEB_LINK_RESOURCES,
  BASIC_LTI_RESOURCES: BASIC_LTI_RESOURCES,
  COURSEWARE_WHITELIST_KEYS: COURSEWARE_WHITELIST_KEYS,
  BENTO_WHITELIST_KEYS: BENTO_WHITELIST_KEYS,
  ASSET_TYPE_VALUES: ASSET_TYPE_VALUES,
  PERMITTED_TYPES: PERMITTED_TYPES,
  LANGUAGE_CODE_MAP: LANGUAGE_CODE_MAP,
  COUNTRY_CODE_MAP: COUNTRY_CODE_MAP,
  LURE_SERVICES: LURE_SERVICES
};