'use strict';

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var merge = require('lodash/merge');
var flatten = require('lodash/flatten');
var compact = require('lodash/compact');
var _ = require('./helpers');

var helpers = require('../../helpers');
var currentYear = helpers.currentYear();
var keywords = helpers.keywords;
var isThin = helpers.isThin;
var isVersion = helpers.isVersion;

var ManifestMetadata = function ManifestMetadata(item, TEMPLATE) {
  _classCallCheck(this, ManifestMetadata);

  var isThinVersion = isThin(TEMPLATE.VERSION);
  var isV1P2 = isVersion(TEMPLATE.VERSION, 'v1p2');
  var overrides = {};

  // LOM: General
  var keyword = keywords(flatten(['McGraw-Hill Education', _.keywords(item)]), ' | ');
  var language = _.languageISO(item);

  // LOM: Copyright
  var lifeCycle = _.copyright(item) || {
    entity: 'McGraw-Hill Education',
    date: currentYear
  };

  // LOM: Educational
  var intendedEndUserRoles = _.intendedEndUserRoles(item, isV1P2).map(function (role) {
    return {
      'lomm:source': 'IMSGLC_CC_Rolesv1p2',
      'lomm:value': role
    };
  });

  var intendedEndUserRole = compact(flatten([intendedEndUserRoles]));

  /**
   * General
   */

  if (language) {
    merge(overrides, {
      'lomm:lom': {
        'lomm:general': {
          'lomm:title': {
            'lomm:string': {
              $: {
                language: language
              }
            }
          },
          'lomm:description': {
            'lomm:string': {
              $: {
                language: language
              }
            }
          },
          'lomm:keyword': {
            'lomm:string': {
              $: {
                language: language
              }
            }
          },
          'lomm:language': language.toLowerCase()
        }
      }
    });
  }

  /**
   * Educational
   */

  if (intendedEndUserRole.length !== 0) {
    merge(overrides, {
      'lomm:lom': {
        'lomm:educational': {
          'lomm:intendedEndUserRole': intendedEndUserRole
        }
      }
    });
  }

  /**
   * Base
   */
  merge(this, {
    'lomm:lom': {
      'lomm:general': {
        'lomm:identifier': {
          'lomm:catalog': 'GUID',
          'lomm:entry': item.id
        },
        'lomm:title': {
          'lomm:string': {
            _: _.title(item)
          }
        },
        'lomm:description': {
          'lomm:string': {
            _: _.description(item)
          }
        },
        'lomm:keyword': {
          'lomm:string': keyword
        }
      },
      'lomm:educational': {
        'lomm:learningResourceType': {
          'lomm:value': isThinVersion ? 'IMS Thin Common Cartridge' : 'IMS Common Cartridge'
        }
      },
      'lomm:lifeCycle': {
        'lomm:contribute': {
          'lomm:role': {
            'lomm:value': 'publisher'
          },
          'lomm:entity': lifeCycle.entity,
          'lomm:date': {
            'lomm:dateTime': lifeCycle.date
          }
        }
      },
      'lomm:rights': {
        'lomm:copyrightAndOtherRestrictions': {
          'lomm:value': 'yes'
        }
      }
    }
  }, overrides);
};

module.exports = ManifestMetadata;