'use strict';

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var merge = require('lodash/merge');
var flatten = require('lodash/flatten');
var _ = require('./helpers');
var OrganizationMetadata = require('./organizationMetadata');

var helpers = require('../../helpers');
var md5 = helpers.md5;

var OrganizationItem = function OrganizationItem(item, TEMPLATE, resources, whitelist) {
  _classCallCheck(this, OrganizationItem);

  var overrides = {};
  // Make internal asset reference id somewhat opaque.
  var guid = md5(item.id);

  if (item.children) {
    item.children.map(function (c) {
      return merge(c, { _parent: _.shallowClone(item) });
    });
  }

  if (_.isResource(item)) {
    overrides = {
      $: {
        identifierref: 'R_' + guid
      },
      metadata: new OrganizationMetadata(item, TEMPLATE)
    };
    resources.push({ item: item, identifier: overrides.$.identifierref });
  }

  merge(this, TEMPLATE.ORGANIZATIONS.ITEM, {
    $: {
      identifier: 'I_' + guid
    },
    title: _.title(item)
  }, overrides);

  /**
   * Recurs if item has children.
   */
  if (_.isNode(item) && _.hasChildren(item, whitelist)) {
    this.item = flatten(item.children.sort(_.orderByType).filter(function (item) {
      return _.isPermitted(item, whitelist);
    }).map(function (item) {
      if (_.isSubsection(item) && _.hasChildren(item, whitelist)) {
        return item.children.filter(function (item) {
          return _.isPermitted(item, whitelist);
        }).map(function (item) {
          return new OrganizationItem(item, TEMPLATE, resources, whitelist);
        });
      }
      return new OrganizationItem(item, TEMPLATE, resources, whitelist);
    }));
  }
};

module.exports = OrganizationItem;