'use strict';

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var merge = require('lodash/merge');
var _ = require('./helpers');

var OrganizationMetadata = function OrganizationMetadata(item, _TEMPLATE) {
  _classCallCheck(this, OrganizationMetadata);

  var overrides = {};

  // LOM: General
  var id = item.id;
  var description = _.description(item);
  var language = _.languageISO(item);

  // LOM: Copyright
  var lifeCycle = _.copyright(item);

  /**
   * General
   */

  if (id) {
    merge(overrides, {
      'lomm:lom': {
        'lomm:general': {
          'lomm:identifier': {
            'lomm:catalog': 'GUID',
            'lomm:entry': id
          }
        }
      }
    });
  }

  if (description) {
    merge(overrides, {
      'lomm:lom': {
        'lomm:general': {
          'lomm:description': {
            'lomm:string': {
              _: description
            }
          }
        }
      }
    });
  }

  if (language) {
    merge(overrides, {
      'lomm:lom': {
        'lomm:general': {
          'lomm:title': {
            'lomm:string': {
              $: {
                language: language
              }
            }
          },
          'lomm:description': {
            'lomm:string': {
              $: {
                language: language
              }
            }
          },
          'lomm:language': language.toLowerCase()
        }
      }
    });
  }

  /**
   * Copyright
   */

  if (lifeCycle) {
    merge(overrides, {
      'lomm:lom': {
        'lomm:lifeCycle': {
          'lomm:contribute': {
            'lomm:role': {
              'lomm:value': 'publisher'
            },
            'lomm:entity': lifeCycle.entity,
            'lomm:date': {
              'lomm:dateTime': lifeCycle.date
            }
          }
        }
      }
    });
  }

  /**
   * Base
   */
  merge(this, {
    'lomm:lom': {
      'lomm:general': {
        'lomm:title': {
          'lomm:string': {
            _: _.title(item)
          }
        }
      }
    }
  }, overrides);
};

module.exports = OrganizationMetadata;