'use strict';

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var merge = require('lodash/merge');
var _ = require('./helpers');
var ResourceMetadata = require('./resourceMetadata');

var WebLinkItem = function WebLinkItem(item, TEMPLATE, identifier) {
  _classCallCheck(this, WebLinkItem);

  merge(this, TEMPLATE.RESOURCES.WEB_LINK, {
    $: {
      identifier: identifier
    },
    metadata: new ResourceMetadata(item, TEMPLATE),
    'wl:webLink': {
      'wl:title': _.title(item),
      'wl:url': {
        $: {
          href: _.url(item)
        }
      }
    }
  });
};

var ExternalWebLinkItem = function ExternalWebLinkItem(item, TEMPLATE, identifier, filename) {
  _classCallCheck(this, ExternalWebLinkItem);

  merge(this, TEMPLATE.EXTERNAL_RESOURCES.WEB_LINK, {
    REFERENCE: {
      $: {
        identifier: identifier
      },
      metadata: new ResourceMetadata(item, TEMPLATE),
      file: {
        $: {
          href: filename
        }
      }
    },
    FILE: {
      title: _.title(item),
      url: {
        $: {
          href: _.url(item)
        }
      }
    }
  });
};

var BasicLTILinkItem = function BasicLTILinkItem(item, TEMPLATE, identifier, _courseXid, _env) {
  _classCallCheck(this, BasicLTILinkItem);

  merge(this, TEMPLATE.RESOURCES.BASIC_LTI_LINK, {
    $: {
      identifier: identifier
    },
    metadata: new ResourceMetadata(item, TEMPLATE)
  });
};

var ExternalBasicLTILinkItem = function ExternalBasicLTILinkItem(item, TEMPLATE, identifier, filename, courseXid, env) {
  _classCallCheck(this, ExternalBasicLTILinkItem);

  var domain = _.lureDomain(env);
  var launchUrl = 'https://' + domain + '/v1/ltihandler/k12';
  var assetXid = _.assetXid(item) || '';
  var assetPlayerType = _.assetPlayerType(item) || '';
  var assetServiceType = _.assetServiceType(item) || '';
  var coursewareXid = courseXid || '';

  merge(this, TEMPLATE.EXTERNAL_RESOURCES.BASIC_LTI_LINK, {
    REFERENCE: {
      $: {
        identifier: identifier
      },
      metadata: new ResourceMetadata(item, TEMPLATE),
      file: {
        $: {
          href: filename
        }
      }
    },
    FILE: {
      'blti:title': _.title(item),
      'blti:description': _.description(item),
      'blti:custom': {
        'lticm:property': [{ $: { name: 'asset_xid' }, _: assetXid }, { $: { name: 'asset_type' }, _: assetPlayerType }, { $: { name: 'asset_service_type' }, _: assetServiceType }, { $: { name: 'courseware_xid' }, _: coursewareXid }]
      },
      // TODO: Verify if `extensions` can be removed entirely.
      'blti:extensions': [{
        $: {
          platform: 'itslearning.com'
        },
        'lticm:property': [{ $: { name: 'privacy_level' }, _: 'public' }]
      }, {
        $: {
          platform: 'canvas.instructure.com'
        },
        'lticm:property': [{ $: { name: 'privacy_level' }, _: 'public' }, { $: { name: 'domain' }, _: domain }]
      }],
      'blti:launch_url': launchUrl,
      'blti:vendor': {
        'lticp:code': 'mheducation.com',
        'lticp:name': 'McGraw-Hill Education'
      }
    }
  });
};

module.exports = {
  WebLinkItem: WebLinkItem,
  ExternalWebLinkItem: ExternalWebLinkItem,
  BasicLTILinkItem: BasicLTILinkItem,
  ExternalBasicLTILinkItem: ExternalBasicLTILinkItem
};