'use strict';

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var merge = require('lodash/merge');
var flatten = require('lodash/flatten');
var compact = require('lodash/compact');
var _ = require('./helpers');
var CurriculumStandardsMetadata = require('./curriculumStandardsMetadata');

var helpers = require('../../helpers');
var keywords = helpers.keywords;

var ResourceMetadata = function ResourceMetadata(item, TEMPLATE) {
  _classCallCheck(this, ResourceMetadata);

  var isThin = helpers.isThin(TEMPLATE.VERSION);
  var isV1P3 = helpers.isVersion(TEMPLATE.VERSION, 'v1p3');
  var overrides = {};

  // LOM: General
  var id = item.id;
  var keyword = keywords(_.keywords(item), ' | ');

  // LOM: Technical

  // LOM: Educational
  var typicalAgeRange = _.gradeRange(item);
  var accessPermission = isThin ? {
    'lomr:source': 'ThinCC_Access_Permission_Vocab',
    'lomr:value': _.accessPermission(item)
  } : null;
  var useType = isThin ? {
    'lomr:source': 'ThinCC_UseType_Vocab',
    'lomr:value': _.useType(item)
  } : null;
  var visibility = isThin ? {
    'lomr:source': 'ThinCC_Visibility_Vocab',
    'lomr:value': _.visibility(item)
  } : null;
  var intendedEndUserRoles = _.intendedEndUserRoles(item).map(function (role) {
    return {
      'lomr:source': 'IMSGLC_CC_Rolesv1p2',
      'lomr:value': role
    };
  });
  var intendedEndUserRole = compact(flatten([accessPermission, useType, visibility, intendedEndUserRoles]));

  // LOM: Copyright
  var lifeCycle = _.copyright(item);

  // CSM
  var curriculum = _.benchmarks(item);

  /**
   * General
   */

  if (isV1P3) {
    merge(overrides, {
      'lomr:lom': {
        'lomr:general': {
          'lomr:description': {
            'lomr:string': _.description(item)
          },
          'lomr:keyword': {
            'lomr:string': keyword
          }
        }
      }
    });
  }

  if (isV1P3 && id) {
    merge(overrides, {
      'lomr:lom': {
        'lomr:general': {
          'lomr:identifier': {
            'lomr:catalog': 'GUID',
            'lomr:entry': id
          }
        }
      }
    });
  }

  /**
   * Educational
   */

  if (isV1P3 && typicalAgeRange) {
    merge(overrides, {
      'lomr:lom': {
        'lomr:educational': {
          'lomr:typicalAgeRange': {
            'lomr:string': typicalAgeRange
          }
        }
      }
    });
  }

  if (isV1P3) {
    merge(overrides, {
      'lomr:lom': {
        'lomr:educational': {
          'lomr:learningResourceType': {
            'lomr:value': _.resourceType(item)
          }
        }
      }
    });
  }

  /**
   * Copyright
   */

  if (isV1P3 && lifeCycle) {
    merge(overrides, {
      'lomr:lom': {
        'lomr:lifeCycle': {
          'lomr:contribute': {
            'lomr:role': {
              'lomr:value': 'publisher'
            },
            'lomr:entity': lifeCycle.entity,
            'lomr:date': {
              'lomr:dateTime': lifeCycle.date
            }
          }
        }
      }
    });
  }

  /**
   * Curriculum
   */

  if (curriculum) {
    merge(overrides, {
      'csm:curriculumStandardsMetadataSet': new CurriculumStandardsMetadata(curriculum, TEMPLATE)
    });
  }

  /**
   * Base
   */
  merge(this, {
    'lomr:lom': {
      'lomr:educational': {
        'lomr:intendedEndUserRole': intendedEndUserRole
      }
    }
  }, overrides);
};

module.exports = ResourceMetadata;