'use strict';

var crypto = require('crypto');
var compact = require('lodash/compact');
var Entities = require('html-entities').AllHtmlEntities;
var entities = new Entities();

module.exports = {
  guid: function guid() {
    var s4 = function s4() {
      return Math.floor((1 + Math.random()) * 0x10000).toString(16).substring(1);
    };
    return s4() + s4() + '-' + s4() + '-' + s4() + '-' + s4() + '-' + s4() + s4() + s4();
  },
  keywords: function keywords(list, delimiter) {
    return compact(list).join(delimiter || ' ');
  },
  stripHtml: function stripHtml(html) {
    html = html || '';
    html = html.replace(/<(?:.|\n|math)*?>/gm, '');
    html = entities.decode(html);
    html = html.replace(/\s+/g, ' ');
    return html.trim();
  },
  buildQueryString: function buildQueryString(params) {
    if (!params) {
      return;
    }

    var qs = [];

    for (var prop in params) {
      qs.push(prop + '=' + params[prop]);
    }

    if (!qs.length) {
      return;
    }

    return '?' + qs.join('&');
  },
  currentYear: function currentYear() {
    return new Date().getFullYear();
  },
  md5: function md5(data) {
    return crypto.createHash('md5').update(String(data)).digest('hex').toUpperCase();
  },
  isThin: function isThin(version) {
    return version.toLowerCase().slice(-1) === 't';
  },
  isVersion: function isVersion(version, match) {
    return String(version).toLowerCase().search(match) !== -1;
  }
};